from setuptools import setup

setup(name='gaussian_binomial_distributions1',
      version='1.1',
      description='Gaussian distributions',
      packages=['gaussian_binomial_distributions1'],
      author = "Gollapinni Karthik",
      zip_safe=False)
